@@ -1,6 +1,6 @@
 # by DCL manual
 =begin
-==AdvancedDCL::Axis
+==NumRu::AdvancedDCL::Axis
 =={W[ɂ
 AxisW[͎Ŏ`߂̃W[łB
 ===W̏ꏊ
@@ -224,107 +224,108 @@ p^ p^̌^ ΉDCLpbP[W
 
 =end
 
-module AdvancedDCL
-  module Axis
-    def param_init
-      @param = Parameter.new(Common.param)
-
-      @param.init("ireset", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("lxinv", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("lyinv", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("lxsub", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("lysub", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("lmatch", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("rmrgn", Float, "usrset", "usrget", 0, 0)
-      @param.init("xfac", Float, "usrset", "usrget", 0, 0)
-      @param.init("yfac", Float, "usrset", "usrget", 0, 0)
-      @param.init("xoff", Float, "usrset", "usrget", 0, 0)
-      @param.init("yoff", Float, "usrset", "usrget", 0, 0)
-      @param.init("dxt", Float, "usrset", "usrget", 0, 0)
-      @param.init("dyt", Float, "usrset", "usrget", 0, 0)
-      @param.init("dxl", Float, "usrset", "usrget", 0, 0)
-      @param.init("dyl", Float, "usrset", "usrget", 0, 0)
-      @param.init("tfact", Float, "usrset", "usrget", 0, 0)
-      @param.init("mxdgtx", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("mxdgty", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nblank1", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nblank2", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nlblx", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nlbly", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nticksx", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("nticksy", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("itypex", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("itypey", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("mxdgtsx", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("mxdgtsy", Fixnum, "usiset", "usiget", 0, 0)
-      @param.init("lprtct", TrueClass, "uslset", "uslget", 0, 0)
-      @param.init("soffxtr", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffxtl", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffxbr", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffxbl", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffxur", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffxul", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffyrt", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffyrb", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffylt", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffylb", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffyut", Float, "usrset", "usrget", 0, 0)
-      @param.init("soffyub", Float, "usrset", "usrget", 0, 0)
-      @param.init("xdtmax", Float, "usrset", "usrget", 0, 0)
-      @param.init("xdtmin", Float, "usrset", "usrget", 0, 0)
-      @param.init("ydtmax", Float, "usrset", "usrget", 0, 0)
-      @param.init("ydtmin", Float, "usrset", "usrget", 0, 0)
-      
-      @param.init("cxttl", String, "uscset", "uscget", 0, 0)
-      @param.init("cyttl", String, "uscset", "uscget", 0, 0)
-      @param.init("cxfmt", String, "uscset", "uscget", 0, 0)
-      @param.init("cyfmt", String, "uscset", "uscget", 0, 0)
-      @param.init("cxside", String, "uscset", "uscget", 0, 0)
-      @param.init("cyside", String, "uscset", "uscget", 0, 0)
-      @param.init("cxspos", String, "uscset", "uscget", 0, 0)
-      @param.init("cyspos", String, "uscset", "uscget", 0, 0)
-      @param.init("cxunit", String, "uscset", "uscget", 0, 0)
-      @param.init("cyunit", String, "uscset", "uscget", 0, 0)
-      @param.init("cblkt", String, "uscset", "uscget", 0, 0)
-      
-      #-------- uzpack parameter ---------
-      @param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
-      @param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
-      @param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
-      @param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
-      @param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
-      @param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
-
-      @param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
-    
-      @param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
+module NumRu
+  module AdvancedDCL
+    module Axis
+      def param_init
+	@param = Parameter.new(Common.param)
 	
-      @param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
-
-      @param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
-      @param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
-      #@param.init("inclpoint", [2, Float], "inclset", "inclget", 1, 1)
-      @temp_param = @param.dup
-      @backup = @param.dup
+	@param.init("ireset", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("lxinv", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("lyinv", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("lxsub", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("lysub", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("lmatch", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("rmrgn", Float, "usrset", "usrget", 0, 0)
+	@param.init("xfac", Float, "usrset", "usrget", 0, 0)
+	@param.init("yfac", Float, "usrset", "usrget", 0, 0)
+	@param.init("xoff", Float, "usrset", "usrget", 0, 0)
+	@param.init("yoff", Float, "usrset", "usrget", 0, 0)
+	@param.init("dxt", Float, "usrset", "usrget", 0, 0)
+	@param.init("dyt", Float, "usrset", "usrget", 0, 0)
+	@param.init("dxl", Float, "usrset", "usrget", 0, 0)
+	@param.init("dyl", Float, "usrset", "usrget", 0, 0)
+	@param.init("tfact", Float, "usrset", "usrget", 0, 0)
+	@param.init("mxdgtx", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("mxdgty", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nblank1", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nblank2", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nlblx", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nlbly", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nticksx", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("nticksy", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("itypex", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("itypey", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("mxdgtsx", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("mxdgtsy", Fixnum, "usiset", "usiget", 0, 0)
+	@param.init("lprtct", TrueClass, "uslset", "uslget", 0, 0)
+	@param.init("soffxtr", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffxtl", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffxbr", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffxbl", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffxur", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffxul", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffyrt", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffyrb", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffylt", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffylb", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffyut", Float, "usrset", "usrget", 0, 0)
+	@param.init("soffyub", Float, "usrset", "usrget", 0, 0)
+	@param.init("xdtmax", Float, "usrset", "usrget", 0, 0)
+	@param.init("xdtmin", Float, "usrset", "usrget", 0, 0)
+	@param.init("ydtmax", Float, "usrset", "usrget", 0, 0)
+	@param.init("ydtmin", Float, "usrset", "usrget", 0, 0)
+	
+	@param.init("cxttl", String, "uscset", "uscget", 0, 0)
+	@param.init("cyttl", String, "uscset", "uscget", 0, 0)
+	@param.init("cxfmt", String, "uscset", "uscget", 0, 0)
+	@param.init("cyfmt", String, "uscset", "uscget", 0, 0)
+	@param.init("cxside", String, "uscset", "uscget", 0, 0)
+	@param.init("cyside", String, "uscset", "uscget", 0, 0)
+	@param.init("cxspos", String, "uscset", "uscget", 0, 0)
+	@param.init("cyspos", String, "uscset", "uscget", 0, 0)
+	@param.init("cxunit", String, "uscset", "uscget", 0, 0)
+	@param.init("cyunit", String, "uscset", "uscget", 0, 0)
+	@param.init("cblkt", String, "uscset", "uscget", 0, 0)
+	
+      #-------- uzpack parameter ---------
+	@param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
+	@param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
+	@param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
+	@param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
+	@param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
+	@param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
+	
+	@param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
+	
+	@param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
+	
+	@param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
+	
+	@param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
+	@param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
+	#@param.init("inclpoint", [2, Float], "inclset", "inclget", 1, 1)
+	@temp_param = @param.dup
+	@backup = @param.dup
       
-    end
+      end
     
-    private :param_init
-
-    def param
-      @param
-    end
+      private :param_init
+      
+      def param
+	@param
+      end
 #------------------- method for parameters----------------------
 
-    def set(key, val)
-      @param[key]=val
-    end
+      def set(key, val)
+	@param[key]=val
+      end
 
 # by kawanabe
 =begin
@@ -339,9 +340,9 @@ module AdvancedDCL
 
 =end
 
-    def get(key)
-      @param[key]
-    end
+      def get(key)
+	@param[key]
+      end
 
 # by kawanabe
 =begin
@@ -355,14 +356,14 @@ module AdvancedDCL
 
 =end
 
-    def zfact(rfact)
-      @param["rsizet1"] = @param["rsizet1"] * rfact
-      @param["rsizet2"] = @param["rsizet2"] * rfact 
-      @param["rsizel1"] = @param["rsizel1"] * rfact
-      @param["rsizel2"] = @param["rsizel2"] * rfact
-      @param["rsizec1"] = @param["rsizec1"] * rfact
-      @param["rsizec2"] = @param["rsizec2"] * rfact
-    end
+      def zfact(rfact)
+	@param["rsizet1"] = @param["rsizet1"] * rfact
+	@param["rsizet2"] = @param["rsizet2"] * rfact 
+	@param["rsizel1"] = @param["rsizel1"] * rfact
+	@param["rsizel2"] = @param["rsizel2"] * rfact
+	@param["rsizec1"] = @param["rsizec1"] * rfact
+	@param["rsizec2"] = @param["rsizec2"] * rfact
+      end
 
 # by DCL manual
 =begin
@@ -377,9 +378,9 @@ module AdvancedDCL
 
 =end
 
-    def title(cxttl, cxunit, cyttl, cyunit)
-      DCL.ussttl(cxttl, cxunit, cyttl, cyunit)
-    end
+      def title(cxttl, cxunit, cyttl, cyunit)
+	DCL.ussttl(cxttl, cxunit, cyttl, cyunit)
+      end
 
 # by DCL manual
 =begin
@@ -398,17 +399,17 @@ module AdvancedDCL
 
 =end
 
-    def xpttl(cside, islct, cttl, px, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
+      def xpttl(cside, islct, cttl, px, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
       
-      #Fig.settrf
-      
-      DCL.uxpttl(cside, islct, cttl, px)
-      @backup.sync
-      @temp_param.clear
-    end
+	#Fig.settrf
+	
+	DCL.uxpttl(cside, islct, cttl, px)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -431,17 +432,17 @@ module AdvancedDCL
 
 =end
 
-    def ypttl(cside, islct, cttl, py, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      #Fig.settrf
-      
-      DCL.uypttl(cside, islct, cttl, py)
-      @backup.sync
-      @temp_param.clear
-    end
+      def ypttl(cside, islct, cttl, py, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	#Fig.settrf
+	
+	DCL.uypttl(cside, islct, cttl, py)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -464,17 +465,17 @@ module AdvancedDCL
 
 =end
 
-    def xmttl(cside, cttl, px, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      #Fig.settrf
-      
-      DCL.uxmttl(cside, cttl, px)
-      @backup.sync
-      @temp_param.clear
-    end
+      def xmttl(cside, cttl, px, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	#Fig.settrf
+	
+	DCL.uxmttl(cside, cttl, px)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -494,17 +495,17 @@ module AdvancedDCL
 
 =end
  
-    def ymttl(cside, cttl, py, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      #Fig.settrf
-      
-      DCL.uymttl(cside, cttl, py)
-      @backup.sync
-      @temp_param.clear
-    end
+      def ymttl(cside, cttl, py, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	#Fig.settrf
+	
+	DCL.uymttl(cside, cttl, py)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -524,17 +525,17 @@ module AdvancedDCL
 
 =end
       
-    def xsttl(cside, cttl, px, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      #Fig.settrf
-      
-      DCL.uxsttl(cside, cttl, px)
-      @backup.sync
-      @temp_param.clear
-    end
+      def xsttl(cside, cttl, px, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	#Fig.settrf
+	
+	DCL.uxsttl(cside, cttl, px)
+	@backup.sync
+	@temp_param.clear
+      end
  
 # by DCL manual
 =begin
@@ -554,17 +555,17 @@ module AdvancedDCL
 
 =end
     
-    def ysttl(cside, cttl, py, temp=nil)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      #Fig.settrf
-      
-      DCL.uysttl(cside, cttl, py)
-      @backup.sync
-      @temp_param.clear
-    end
+      def ysttl(cside, cttl, py, temp=nil)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	#Fig.settrf
+	
+	DCL.uysttl(cside, cttl, py)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -584,31 +585,31 @@ module AdvancedDCL
 
 =end
 
-    def draw(x=nil, y=nil, temp=nil)
-      rundef = Fig.rundef
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==rundef || y==rundef)
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
-      end
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
+      def draw(x=nil, y=nil, temp=nil)
+	rundef = Fig.rundef
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==rundef || y==rundef)
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
     
-      DCL.usdaxs
-      @backup.sync
-      @temp_param.clear
-    end
+	DCL.usdaxs
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -626,28 +627,28 @@ module AdvancedDCL
 
 =end
 
-    def xax(cside, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def xax(cside, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.usxaxs(cside)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-
-      Fig.settrf
-
-      DCL.usxaxs(cside)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -666,28 +667,28 @@ module AdvancedDCL
 
 =end
   
-    def yax(cside, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def yax(cside, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.usyaxs(cside)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.usyaxs(cside)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -706,35 +707,36 @@ module AdvancedDCL
 
 =end
   
-    module_function :param_init
-    module_function :param
-    module_function :zfact
-    module_function :xpttl
-    module_function :ypttl
-    module_function :xmttl
-    module_function :ymttl
-    module_function :xsttl
-    module_function :ysttl
-    module_function :draw
-    module_function :set
-    module_function :get
-    module_function :title
-    module_function :xax
-    module_function :yax
-
-    param_init
-
-    @param.keys.each{|i|
-      eval "def #{i}; @param['#{i}']; end"
-      eval "def #{i}=(val); set('#{i}', val); end"
-    }
-    
-    @param.keys.each{|i|
-      eval "module_function :#{i}"
-      eval "module_function :#{i}="
-    }
+      module_function :param_init
+      module_function :param
+      module_function :zfact
+      module_function :xpttl
+      module_function :ypttl
+      module_function :xmttl
+      module_function :ymttl
+      module_function :xsttl
+      module_function :ysttl
+      module_function :draw
+      module_function :set
+      module_function :get
+      module_function :title
+      module_function :xax
+      module_function :yax
+      
+      param_init
+      
+      @param.keys.each{|i|
+	eval "def #{i}; @param['#{i}']; end"
+	eval "def #{i}=(val); set('#{i}', val); end"
+      }
+      
+      @param.keys.each{|i|
+	eval "module_function :#{i}"
+	eval "module_function :#{i}="
+      }
+    end
   end
 end
 
-require "dcl/log"
-require "dcl/linear"
+require "numru/advanceddcl/log"
+require "numru/advanceddcl/linear"
