@@ -1,6 +1,6 @@
 # by DCL manual
 =begin
-==AdvancedDCL::Dateaxis
+==NumRu::AdvancedDCL::Dateaxis
 ==={W[ɂ
 DateaxisW[͓t`߂̃W[łB
 悵悤ƂWɂĂ, PʂƂĐKϊݒ肵ĂȂ΂ȂȂ. ܂W̍, [U[Wn(UC)ɂ0ɑʒu炨Ȃ. , Ƃ11131܂31r[|[gςɊ蓖ĂƂ,EChE̗[l(0, 30)Ǝw肷. 
@@ -25,30 +25,31 @@ p^ p^̌^ ΉDCLpbP[W
 
 =end
 
-module AdvancedDCL
-  module Dateaxis
-    def param_init
-      @param = Parameter.new(Common.param)
-
-      @param.init("nday", Fixnum, "uciset", "uciget", 0, 0)
-      @param.init("nchar", Fixnum, "uciset", "uciget", 0, 0)
-      @param.init("lower", TrueClass, "uclset", "uclget", 0, 0)
-      @param.init("iundef", Fixnum, "uciset", "uciget", 0, 0)
-
-      @axisparam = Axis.param
-      @temp_param = @param.dup
-      @backup = @param.dup
-
-    end
-    
-    private :param_init
-
+module NumRu
+  module AdvancedDCL
+    module Dateaxis
+      def param_init
+	@param = Parameter.new(Common.param)
+	
+	@param.init("nday", Fixnum, "uciset", "uciget", 0, 0)
+	@param.init("nchar", Fixnum, "uciset", "uciget", 0, 0)
+	@param.init("lower", TrueClass, "uclset", "uclget", 0, 0)
+	@param.init("iundef", Fixnum, "uciset", "uciget", 0, 0)
+	
+	@axisparam = Axis.param
+	@temp_param = @param.dup
+	@backup = @param.dup
+	
+      end
+      
+      private :param_init
+      
 #------------------- method for parameters----------------------
-
-    def set(key, val)
-      @param[key]=val
-    end
-
+      
+      def set(key, val)
+	@param[key]=val
+      end
+      
 # by kawanabe
 =begin
 ---Dateaxis.set(key, val)
@@ -62,9 +63,9 @@ module AdvancedDCL
 
 =end
 
-    def get(key)
-      @param[key]
-    end
+      def get(key)
+	@param[key]
+      end
 
 # by kawanabe
 =begin
@@ -78,29 +79,29 @@ module AdvancedDCL
 
 =end
 
-    def xdraw(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def xdraw(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucxacl(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucxacl(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -120,29 +121,29 @@ module AdvancedDCL
 
 =end 
 
-    def ydraw(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def ydraw(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucyacl(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucyacl(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -162,29 +163,29 @@ module AdvancedDCL
 
 =end 
 
-    def xady(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def xady(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucxady(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucxady(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -207,30 +208,30 @@ module AdvancedDCL
 
 =end
     
-    def yady(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def yady(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucyady(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
       
-      Fig.settrf
-      
-      DCL.ucyady(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
-
 # by DCL manual
 =begin
 ---Dateaxis.yady(cside, jd0, nd, x=nil, y=nil, temp=nil)
@@ -252,29 +253,29 @@ module AdvancedDCL
 
 =end
     
-    def xamn(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def xamn(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucxamn(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucxamn(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -297,29 +298,29 @@ module AdvancedDCL
 
 =end
     
-    def yamn(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def yamn(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucyamn(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucyamn(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -342,29 +343,29 @@ module AdvancedDCL
 
 =end
     
-    def xayr(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def xayr(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucxayr(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucxayr(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -386,29 +387,29 @@ module AdvancedDCL
 
 =end
     
-    def yayr(cside, jd0, nd, x=nil, y=nil, temp=nil)
-      if(x.is_a?(Hash))
-	temp = x
-      elsif((x.is_a?(NArray))&&(x.rank==2))
-	y = x.shape[1].to_f
-	x = x.shape[0].to_f
-	Basics.checkundef(x, y)
-      elsif(Basics.typearray(x) && Basics.typearray(y))
-	Basics.checkundef(x, y)
-      elsif(x==nil&&y==nil)
-	Basics.checkundef(1.0, 1.0)
+      def yayr(cside, jd0, nd, x=nil, y=nil, temp=nil)
+	if(x.is_a?(Hash))
+	  temp = x
+	elsif((x.is_a?(NArray))&&(x.rank==2))
+	  y = x.shape[1].to_f
+	  x = x.shape[0].to_f
+	  Basics.checkundef(x, y)
+	elsif(Basics.typearray(x) && Basics.typearray(y))
+	  Basics.checkundef(x, y)
+	elsif(x==nil&&y==nil)
+	  Basics.checkundef(1.0, 1.0)
+	end
+	@param.sync
+	@axisparam.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.ucyayr(cside, jd0, nd)
+	@backup.sync
+	@temp_param.clear
       end
-      @param.sync
-      @axisparam.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      
-      DCL.ucyayr(cside, jd0, nd)
-      @backup.sync
-      @temp_param.clear
-    end
 
 # by DCL manual
 =begin
@@ -430,28 +431,29 @@ module AdvancedDCL
 
 =end
 
-    module_function :param_init
-    module_function :xdraw
-    module_function :ydraw
-    module_function :xady
-    module_function :yady
-    module_function :set
-    module_function :get
-    module_function :xamn
-    module_function :yamn
-    module_function :xayr
-    module_function :yayr
-
-    param_init
-
-    @param.keys.each{|i|
-      eval "def #{i}; @param['#{i}']; end"
-      eval "def #{i}=(val); set('#{i}', val); end"
-    }
-    
-    @param.keys.each{|i|
-      eval "module_function :#{i}"
-      eval "module_function :#{i}="
-    }
+      module_function :param_init
+      module_function :xdraw
+      module_function :ydraw
+      module_function :xady
+      module_function :yady
+      module_function :set
+      module_function :get
+      module_function :xamn
+      module_function :yamn
+      module_function :xayr
+      module_function :yayr
+      
+      param_init
+      
+      @param.keys.each{|i|
+	eval "def #{i}; @param['#{i}']; end"
+	eval "def #{i}=(val); set('#{i}', val); end"
+      }
+      
+      @param.keys.each{|i|
+	eval "module_function :#{i}"
+	eval "module_function :#{i}="
+      }
+    end
   end
 end
