@@ -1,6 +1,6 @@
 require "narray"
-require "dcl/advanced"
-include AdvancedDCL
+require "numru/advanceddcl"
+include NumRu::AdvancedDCL
 include NMath
 
 
