@@ -1,6 +1,6 @@
 require "narray"
-require "dcl/advanced"
-include AdvancedDCL
+require "numru/advanceddcl"
+include NumRu::AdvancedDCL
 include NMath
 
 
@@ -15,7 +15,7 @@ y[0] = 0.5
 for n in 0..nmax-1
   y[n+1] = r*y[n]*(1.0-y[n])
 end
-yave = rave(y, nmax+1, 1)
+yave = DCL.rave(y, nmax+1, 1)
 y = -4 * (y - yave)
 
 #-- graph ---
