@@ -1,5 +1,5 @@
-require "dcl/advanced"
-include AdvancedDCL
+require "numru/advanceddcl"
+include NumRu::AdvancedDCL
 include NMath
 
 
