@@ -1,7 +1,7 @@
 require "narray"
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 
 n = 9
 y = NArray.sfloat(n)
