@@ -1,7 +1,7 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
-include Math
+include NumRu::AdvancedDCL
+include NMath
 
 kmax = 4
 nn = 73
