@@ -1,6 +1,6 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 
 Dev.open("X",true)
 Frame.mgn(0.1, 0.1, 0.05, 0.05)
