@@ -1,6 +1,6 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 
 x = [-7.5, 7.5, 7.5, -7.5, -7.5]
 y = [-7.5, -7.5, 7.5, 7.5, -7.5]
