@@ -1,6 +1,6 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 include NMath
 
 
