@@ -1,7 +1,7 @@
 require "narray"
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 include NMath
 
 
@@ -41,7 +41,7 @@ for j in 0..ny-1
       v[i,j] = rmiss
     else
       u[i,j] = (p[i,j-1] - p[i,j+1]) * fact
-      v[i,j] = (p[imod(i+1,nx-1),j] - p[imod(i-1,nx-1),j]) * fact
+      v[i,j] = (p[DCL.imod(i+1,nx-1),j] - p[DCL.imod(i-1,nx-1),j]) * fact
     end
   end
 end
