@@ -1,7 +1,7 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
-include Math
+include NumRu::AdvancedDCL
+include NMath
 
 n = 100
 x = NArray.sfloat(n)
