@@ -1,8 +1,8 @@
 require "narray"
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
-include Math
+include NumRu::AdvancedDCL
+include NMath
 
 nt = 51
 nz = 21
