@@ -1,6 +1,6 @@
-require "dcl/advanced"
+require "numru/advanceddcl"
 
-include AdvancedDCL
+include NumRu::AdvancedDCL
 
 x1 = -180.0
 x2 = +180.0
