@@ -1,6 +1,6 @@
 # by DCL manual
 =begin
-==AdvancedDCL::Axis::Lin
+==NumRu::AdvancedDCL::Axis::Lin
 ==={W[ɂ
 ===Tv
 Axis::LinW[͒Wn̍Wvbg邽߂̃W[ł.
@@ -72,107 +72,108 @@ Axis::LinW[͒Wn̍Wvbg邽߂̃W[ł.
 
 =end
 
-module AdvancedDCL
-  module Axis
-    module Lin
-      def param_init
-	@param = Parameter.new(Axis.param)
-	@param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
+module NumRu
+  module AdvancedDCL
+    module Axis
+      module Lin
+	def param_init
+	  @param = Parameter.new(Axis.param)
+	  @param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
+	  
+	  @param.init("irotlxb", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotlxt", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotlxu", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotlyl", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotlyr", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotlyu", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @param.init("irotcxb", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotcxt", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotcxu", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotcyl", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotcyr", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("irotcyu", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @param.init("icentxb", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("icentxt", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("icentxu", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("icentyl", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("icentyr", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("icentyu", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @param.init("indext0", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("indext1", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("indext2", Fixnum, "uziset", "uziget", 0, 0)
 	
-	@param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("indexl0", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("indexl1", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("indexl2", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("loffset", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("xoffset", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("yoffset", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("xfact", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("yfact", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("pad1", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("pad2", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("iflag", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("lbtwn", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("rbtwn", Fixnum, "uziset", "uziget", 0, 0)
+	  @param.init("lbound", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("lbmsg", TrueClass, "uzlset", "uzlget", 0, 0)
+	  @param.init("inner", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @param.init("cxfmt", String, "uxsfmt", "uxqfmt", 1, 1)
+	  @param.init("cyfmt", String, "uysfmt", "uyqfmt", 1, 1)
+	  
+	  @param.init("roffxu", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("roffyu", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgxb", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgxt", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgxu", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgyl", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgyr", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("rofgyu", Float, "uzrset", "uzrget", 0, 0)
+	  
+	  @param.init("roffxt", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("roffxb", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("roffyl", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("roffyr", Float, "uzrset", "uzrget", 0, 0)
+	  @param.init("iundef", Fixnum, "uziset", "uziget", 0, 0)
+	  
+	  @temp_param = @param.dup
+	  @backup = @param.dup
+	end
 	
-	@param.init("irotlxb", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotlxt", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotlxu", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotlyl", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotlyr", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotlyu", Fixnum, "uziset", "uziget", 0, 0)
-	
-	@param.init("irotcxb", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotcxt", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotcxu", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotcyl", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotcyr", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("irotcyu", Fixnum, "uziset", "uziget", 0, 0)
-	
-	@param.init("icentxb", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("icentxt", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("icentxu", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("icentyl", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("icentyr", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("icentyu", Fixnum, "uziset", "uziget", 0, 0)
-	
-	@param.init("indext0", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("indext1", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("indext2", Fixnum, "uziset", "uziget", 0, 0)
-	
-	@param.init("indexl0", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("indexl1", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("indexl2", Fixnum, "uziset", "uziget", 0, 0)
-	
-	@param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
-    
-	@param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
-	
-	@param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
-	
-	@param.init("loffset", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("xoffset", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("yoffset", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("xfact", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("yfact", Float, "uzrset", "uzrget", 0, 0)
-
-	@param.init("pad1", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("pad2", Float, "uzrset", "uzrget", 0, 0)
-
-	@param.init("iflag", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("lbtwn", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("rbtwn", Fixnum, "uziset", "uziget", 0, 0)
-	@param.init("lbound", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("lbmsg", TrueClass, "uzlset", "uzlget", 0, 0)
-	@param.init("inner", Fixnum, "uziset", "uziget", 0, 0)
-
-	@param.init("cxfmt", String, "uxsfmt", "uxqfmt", 1, 1)
-	@param.init("cyfmt", String, "uysfmt", "uyqfmt", 1, 1)
-	
-	@param.init("roffxu", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("roffyu", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgxb", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgxt", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgxu", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgyl", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgyr", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("rofgyu", Float, "uzrset", "uzrget", 0, 0)
-	
-	@param.init("roffxt", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("roffxb", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("roffyl", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("roffyr", Float, "uzrset", "uzrget", 0, 0)
-	@param.init("iundef", Fixnum, "uziset", "uziget", 0, 0)
-
-	@temp_param = @param.dup
-	@backup = @param.dup
-      end
-      
-      private :param_init
+	private :param_init
 
 #------------------- method for parameters----------------------
 
-      def set(key, val)
-	@param[key] = val
-      end  
+	def set(key, val)
+	  @param[key] = val
+	end  
 
 # by kawanabe
 =begin
@@ -186,9 +187,9 @@ module AdvancedDCL
         Axis::Lin.set("labelxb", false)      # X-bottom Ƀx`Ȃ悤ɐݒ
 
 =end
-      def get(key)
-	@param[key]
-      end
+	def get(key)
+	  @param[key]
+	end
 
 # by kawanabe
 =begin
@@ -202,14 +203,14 @@ module AdvancedDCL
 
 =end
 
-      def zfact(rfact)
-	@param["rsizet1"] = @param["rsizet1"] * rfact
-	@param["rsizet2"] = @param["rsizet2"] * rfact 
-	@param["rsizel1"] = @param["rsizel1"] * rfact
-	@param["rsizel2"] = @param["rsizel2"] * rfact
-	@param["rsizec1"] = @param["rsizec1"] * rfact
-	@param["rsizec2"] = @param["rsizec2"] * rfact
-      end
+	def zfact(rfact)
+	  @param["rsizet1"] = @param["rsizet1"] * rfact
+	  @param["rsizet2"] = @param["rsizet2"] * rfact 
+	  @param["rsizel1"] = @param["rsizel1"] * rfact
+	  @param["rsizel2"] = @param["rsizel2"] * rfact
+	  @param["rsizec1"] = @param["rsizec1"] * rfact
+	  @param["rsizec2"] = @param["rsizec2"] * rfact
+	end
 
 # by DCL manual
 =begin
@@ -227,28 +228,28 @@ module AdvancedDCL
 #----------------------------------------------------------
 #------------ draw method ----------------------
 
-      def xaxdv(cside, dx1, dx2, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def xaxdv(cside, dx1, dx2, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uxaxdv(cside, dx1, dx2)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	Fig.settrf
-
-	DCL.uxaxdv(cside, dx1, dx2)
-	@backup.sync
-	@temp_param.clear
-      end
 
 # by DCL manual
 =begin
@@ -272,29 +273,29 @@ module AdvancedDCL
 
 =end
 
-      def yaxdv(cside, dy1, dy2, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def yaxdv(cside, dy1, dy2, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uyaxdv(cside, dy1, dy2)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
 	
-	Fig.settrf
-		
-	DCL.uyaxdv(cside, dy1, dy2)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.yaxdv(cside, dy1, dy2, x=nil, y=nil, temp=nil)
@@ -317,40 +318,40 @@ module AdvancedDCL
 
 =end
 
-      def xaxlb(cside, ux1, ux2, ch, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
-	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	Fig.settrf
-	
-	nc = 1
-	ch.each{|i|
-	  if(i.type != String)
-	    raise ArgumentError, "elements of the 4th argument must be String"
+	def xaxlb(cside, ux1, ux2, ch, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
 	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
 	  
-	  if(i.length > nc)
-	    nc = i.length
-	  end
-	}
+	  Fig.settrf
+	  
+	  nc = 1
+	  ch.each{|i|
+	    if(i.type != String)
+	      raise ArgumentError, "elements of the 4th argument must be String"
+	    end
+	    
+	    if(i.length > nc)
+	      nc = i.length
+	    end
+	  }
+	  
+	  DCL.uxaxlb(cside, ux1, ux1.length, ux2, ch, nc, ux2.length)
+	  @backup.sync
+	  @temp_param.clear
+	end
 	
-	DCL.uxaxlb(cside, ux1, ux1.length, ux2, ch, nc, ux2.length)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.xaxlb(cside, ux1, ux2, ch, x=nil, y=nil, temp=nil)
@@ -370,39 +371,39 @@ module AdvancedDCL
     (3)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B      
 =end
         
-      def yaxlb(cside, uy1, uy2, ch, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
-	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	#Fig.settrf
-	
-	nc = 1
-	ch.each{|i|
-	  if(i.type != String)
-	    raise ArgumentError, "elements of the 4th argument must be String"
+	def yaxlb(cside, uy1, uy2, ch, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
 	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
 	  
-	  if(i.length > nc)
-	    nc = i.length
-	  end
-	}
+	  #Fig.settrf
 	
-	DCL.uyaxlb(cside, uy1, uy1.length, uy2, ch, nc, uy2.length)
-	@backup.sync
-	@temp_param.clear
-      end
+	  nc = 1
+	  ch.each{|i|
+	    if(i.type != String)
+	      raise ArgumentError, "elements of the 4th argument must be String"
+	    end
+	    
+	    if(i.length > nc)
+	      nc = i.length
+	    end
+	  }
+	  
+	  DCL.uyaxlb(cside, uy1, uy1.length, uy2, ch, nc, uy2.length)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
  
 # by DCL manual
@@ -424,29 +425,29 @@ module AdvancedDCL
     (3)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B
 =end
       
-      def xpaxs(cside, islct, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def xpaxs(cside, islct, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uxpaxs(cside, islct)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
 	
-	Fig.settrf
-	
-	DCL.uxpaxs(cside, islct)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.xpaxs(cside, islct, x=nil, y=nil, temp=nil)
@@ -472,29 +473,29 @@ module AdvancedDCL
 
 =end
  
-      def ypaxs(cside, islct, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def ypaxs(cside, islct, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uypaxs(cisde, islct)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
 	
-	Fig.settrf
-	
-	DCL.uypaxs(cisde, islct)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.ypaxs(cside, islct, x=nil, y=nil, temp=nil)
@@ -520,39 +521,39 @@ module AdvancedDCL
 
 =end
       
-      def xplbl(cside, islct, ux, ch, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
-	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	Fig.settrf
-		
-	nc = 1
-	ch.each{|i|
-	  if(i.type != String)
-	    raise ArgumentError, "elements of the 4th argument must be String"
+	def xplbl(cside, islct, ux, ch, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
 	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
 	  
-	  if(i.length > nc)
-	    nc = i.length
-	  end
-	}
-	
-	DCL.uxplbl(cside, islct, ux, ch, nc, ux.length)
-	@backup.sync
-	@temp_param.clear
-      end
+	  Fig.settrf
+	  
+	  nc = 1
+	  ch.each{|i|
+	    if(i.type != String)
+	      raise ArgumentError, "elements of the 4th argument must be String"
+	    end
+	    
+	    if(i.length > nc)
+	      nc = i.length
+	    end
+	  }
+	  
+	  DCL.uxplbl(cside, islct, ux, ch, nc, ux.length)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
 # by DCL manual
 =begin
@@ -583,39 +584,39 @@ module AdvancedDCL
 
 =end
  
-      def yplbl(cside, islct, uy, ch, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
-	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
+	def yplbl(cside, islct, uy, ch, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
 	
 	Fig.settrf
-		
-	nc = 1
-	ch.each{|i|
-	  if(i.type != String)
-	    raise ArgumentError, "elements of the 4th argument must be String"
-	  end
 	  
-	  if(i.length > nc)
-	    nc = i.length
-	  end
-	}
-	
-	DCL.uyplbl(cside, islct, uy, ch, nc, uy.length)
-	@backup.sync
-	@temp_param.clear
-      end
+	  nc = 1
+	  ch.each{|i|
+	    if(i.type != String)
+	      raise ArgumentError, "elements of the 4th argument must be String"
+	    end
+	    
+	    if(i.length > nc)
+	      nc = i.length
+	    end
+	  }
+	  
+	  DCL.uyplbl(cside, islct, uy, ch, nc, uy.length)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
       
 # by DCL manual
@@ -647,28 +648,28 @@ module AdvancedDCL
 
 =end
 
-      def xpnum(cside, islct, ux, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def xpnum(cside, islct, ux, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uxpnum(cside, islct, ux, ux.length)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	Fig.settrf
-		
-	DCL.uxpnum(cside, islct, ux, ux.length)
-	@backup.sync
-	@temp_param.clear
-      end
 
 # by DCL manual
 =begin
@@ -690,29 +691,29 @@ module AdvancedDCL
 
 =end
 
-      def ypnum(cside, islct, uy, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def ypnum(cside, islct, uy, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uypnum(cside, islct, uy, uy.length)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-
-	Fig.settrf
-		
-	DCL.uypnum(cside, islct, uy, uy.length)
-	@backup.sync
-	@temp_param.clear
-      end
-
+	
 # by DCL manual
 =begin
 ---Axis::Lin.ypnum(cside, islct, uy, x=nil, y=nil, temp=nil)
@@ -733,29 +734,29 @@ module AdvancedDCL
 
 =end
       
-      def xptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
+	def xptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
+	  
+	  DCL.uxptmk(cside, islct, ux, ux.length)
+	  @backup.sync
+	  @temp_param.clear
 	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-
-	Fig.settrf
 	
-	DCL.uxptmk(cside, islct, ux, ux.length)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.xptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
@@ -777,28 +778,28 @@ module AdvancedDCL
 
 =end
 
-      def yptmk(cside, islct, uy, x=nil, y=nil, temp=nil)
-	if(x.is_a?(Hash))
-	  temp = x
-	elsif((x.is_a?(NArray))&&(x.rank==2))
-	  y = x.shape[1].to_f
-	  x = x.shape[0].to_f
-	  Basics.checkundef(x, y)
-	elsif(Basics.typearray(x) && Basics.typearray(y))
-	  Basics.checkundef(x, y)
-	elsif(x==nil&&y==nil)
-	  Basics.checkundef(1.0, 1.0)
-	end
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	Fig.settrf
+	def yptmk(cside, islct, uy, x=nil, y=nil, temp=nil)
+	  if(x.is_a?(Hash))
+	    temp = x
+	  elsif((x.is_a?(NArray))&&(x.rank==2))
+	    y = x.shape[1].to_f
+	    x = x.shape[0].to_f
+	    Basics.checkundef(x, y)
+	  elsif(Basics.typearray(x) && Basics.typearray(y))
+	    Basics.checkundef(x, y)
+	  elsif(x==nil&&y==nil)
+	    Basics.checkundef(1.0, 1.0)
+	  end
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  Fig.settrf
 		
-	DCL.uyptmk(cside, islct, uy, uy.length)
-	@backup.sync
-	@temp_param.clear
-      end
+	  DCL.uyptmk(cside, islct, uy, uy.length)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
 # by DCL manual
 =begin
@@ -821,18 +822,18 @@ module AdvancedDCL
 
 =end
       
-      def xpttl(cside, islct, cttl, px, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
+	def xpttl(cside, islct, cttl, px, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uxpttl(cside, islct, cttl, px)
+	  @backup.sync
+	  @temp_param.clear
+	end
 	
-	#Fig.settrf
-		
-	DCL.uxpttl(cside, islct, cttl, px)
-	@backup.sync
-	@temp_param.clear
-      end
-
 # by DCL manual
 =begin
 ---Axis::Lin.xpttl(cside, islct, cttl, px, temp=nil)
@@ -854,18 +855,18 @@ module AdvancedDCL
 
 =end
 
-      def ypttl(cside, islct, cttl, py, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-
-	#Fig.settrf
-		
-	DCL.uypttl(cside, islct, cttl, py)
-	@backup.sync
-	@temp_param.clear
-      end
-
+	def ypttl(cside, islct, cttl, py, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uypttl(cside, islct, cttl, py)
+	  @backup.sync
+	  @temp_param.clear
+	end
+	
 # by DCL manual
 =begin
 ---Axis::Lin.ypttl(cside, islct, cttl, py, temp=nil)
@@ -887,17 +888,17 @@ module AdvancedDCL
 
 =end
 
-      def xmttl(cside, cttl, px, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	#Fig.settrf
-	
-	DCL.uxmttl(cside, cttl, px)
-	@backup.sync
-	@temp_param.clear
-      end
+	def xmttl(cside, cttl, px, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uxmttl(cside, cttl, px)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
 # by DCL manual
 =begin
@@ -917,17 +918,17 @@ module AdvancedDCL
 
 =end
  
-      def ymttl(cside, cttl, py, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-
-	#Fig.settrf
-	
-	DCL.uymttl(cside, cttl, py)
-	@backup.sync
-	@temp_param.clear
-      end
+	def ymttl(cside, cttl, py, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uymttl(cside, cttl, py)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
 # by DCL manual
 =begin
@@ -946,19 +947,19 @@ module AdvancedDCL
     (2)̃\bh UYPTTL (ISLCT=2)g ^Cg`Ă.
 
 =end
-      
-      def xsttl(cside, cttl, px, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
 	
-	#Fig.settrf
+	def xsttl(cside, cttl, px, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uxsttl(cside, cttl, px)
+	  @backup.sync
+	  @temp_param.clear
+	end
 	
-	DCL.uxsttl(cside, cttl, px)
-	@backup.sync
-	@temp_param.clear
-      end
- 
 # by DCL manual
 =begin
 ---Axis::Lin.xsttl(cside, cttl, px, temp=nil)
@@ -977,17 +978,17 @@ module AdvancedDCL
 
 =end
     
-      def ysttl(cside, cttl, py, temp=nil)
-	@param.sync
-	@backup = @temp_param.set(temp, @param, @backup)
-	@temp_param.sync
-	
-	#Fig.settrf
-		
-	DCL.uysttl(cside, cttl, py)
-	@backup.sync
-	@temp_param.clear
-      end
+	def ysttl(cside, cttl, py, temp=nil)
+	  @param.sync
+	  @backup = @temp_param.set(temp, @param, @backup)
+	  @temp_param.sync
+	  
+	  #Fig.settrf
+	  
+	  DCL.uysttl(cside, cttl, py)
+	  @backup.sync
+	  @temp_param.clear
+	end
 
 # by DCL manual
 =begin
@@ -1006,61 +1007,62 @@ module AdvancedDCL
     (2)̃\bh UYPTTL (ISLCT=1)g ^Cg`Ă.
 
 =end
-           
-      def xsaxz(cside, roffx)
-	DCL.uxsaxz(cside, roffx)
-      end
-
-      def ysaxz(cside, roffy)
-	DCL.uysaxz(cside, roffy)
-      end
-
-      def xsaxs(cside)
-	DCL.uxsaxs(cside)
-      end
-
-      def ysaxs(cside)
-	DCL.uysaxs(cside)
-      end
-
-      module_function :param_init
-      module_function :set
-      module_function :get
-      module_function :zfact
-      module_function :xaxdv
-      module_function :yaxdv
-      module_function :xaxlb
-      module_function :yaxlb
-      module_function :xpaxs
-      module_function :ypaxs
-      module_function :xplbl
-      module_function :yplbl
-      module_function :xpnum
-      module_function :ypnum
-      module_function :xptmk
-      module_function :yptmk
-      module_function :xpttl
-      module_function :ypttl
-      module_function :xmttl
-      module_function :ymttl
-      module_function :xsttl
-      module_function :ysttl
-      module_function :xsaxz
-      module_function :ysaxz
-      module_function :xsaxs
-      module_function :ysaxs
-     
-      param_init
-
-      @param.keys.each{|i|
-	eval "def #{i}; @param['#{i}']; end"
-	eval "def #{i}=(val); set('#{i}', val); end"
-      }
+	
+	def xsaxz(cside, roffx)
+	  DCL.uxsaxz(cside, roffx)
+	end
+	
+	def ysaxz(cside, roffy)
+	  DCL.uysaxz(cside, roffy)
+	end
+	
+	def xsaxs(cside)
+	  DCL.uxsaxs(cside)
+	end
+	
+	def ysaxs(cside)
+	  DCL.uysaxs(cside)
+	end
+	
+	module_function :param_init
+	module_function :set
+	module_function :get
+	module_function :zfact
+	module_function :xaxdv
+	module_function :yaxdv
+	module_function :xaxlb
+	module_function :yaxlb
+	module_function :xpaxs
+	module_function :ypaxs
+	module_function :xplbl
+	module_function :yplbl
+	module_function :xpnum
+	module_function :ypnum
+	module_function :xptmk
+	module_function :yptmk
+	module_function :xpttl
+	module_function :ypttl
+	module_function :xmttl
+	module_function :ymttl
+	module_function :xsttl
+	module_function :ysttl
+	module_function :xsaxz
+	module_function :ysaxz
+	module_function :xsaxs
+	module_function :ysaxs
+	
+	param_init
+	
+	@param.keys.each{|i|
+	  eval "def #{i}; @param['#{i}']; end"
+	  eval "def #{i}=(val); set('#{i}', val); end"
+	}
       
-      @param.keys.each{|i|
-	eval "module_function :#{i}"
-	eval "module_function :#{i}="
-      }
+	@param.keys.each{|i|
+	  eval "module_function :#{i}"
+	  eval "module_function :#{i}="
+	}
+      end
     end
   end
 end
