@@ -1,6 +1,6 @@
 # by DCL manual
 =begin
-==AdvancedDCL::Tone
+==NumRu::AdvancedDCL::Tone
 ==={W[ɂ
 ToneW[̓J[g[(mN)\邽߂̃W[łB
 ʂ킯UWnłȂ̂, ׂĂ̐KϊɑΉĂ. 
@@ -69,42 +69,43 @@ p^ p^̌^ ΉDCLpbP[W
 
 =end
 
-module AdvancedDCL
-  module Tone
-    def param_init
-      @param = Parameter.new(Common.param)
-
+module NumRu
+  module AdvancedDCL
+    module Tone
+      def param_init
+	@param = Parameter.new(Common.param)
+	
 #--------------------- uepack parameter -------------------------
-      @param.init("icolor1", Fixnum, "ueiset", "ueiget", 0, 0)
-      @param.init("icolor2", Fixnum, "ueiset", "ueiget", 0, 0)
-      @param.init("ipat", Fixnum, "ueiset", "ueiget", 0, 0)
-      @param.init("nlev", Fixnum, "ueiset", "ueiget", 0, 0)
-      @param.init("icycle", Fixnum, "ueiset", "ueiget", 0, 0)
-      @param.init("lbound", TrueClass, "uelset", "uelget", 0, 0)
-      @param.init("ltone", TrueClass, "uelset", "uelget", 0, 0)
-      @param.init("rlev", Float, "uerset", "uerget", 0, 0)
+	@param.init("icolor1", Fixnum, "ueiset", "ueiget", 0, 0)
+	@param.init("icolor2", Fixnum, "ueiset", "ueiget", 0, 0)
+	@param.init("ipat", Fixnum, "ueiset", "ueiget", 0, 0)
+	@param.init("nlev", Fixnum, "ueiset", "ueiget", 0, 0)
+	@param.init("icycle", Fixnum, "ueiset", "ueiget", 0, 0)
+	@param.init("lbound", TrueClass, "uelset", "uelget", 0, 0)
+	@param.init("ltone", TrueClass, "uelset", "uelget", 0, 0)
+	@param.init("rlev", Float, "uerset", "uerget", 0, 0)
 
 #--------------------- sgpack parameter -------------------------
-      @param.init("lsoftf", TrueClass, "sglset", "sglget", 0, 0)
-      @param.init("lcl2tn", TrueClass, "sglset", "sglget", 0, 0)
-      @param.init("tnblen", Float, "sgrset", "sgrget", 0, 0)
-      @param.init("irmode", Fixnum, "sgiset", "sgiget", 0, 0)
-
+	@param.init("lsoftf", TrueClass, "sglset", "sglget", 0, 0)
+	@param.init("lcl2tn", TrueClass, "sglset", "sglget", 0, 0)
+	@param.init("tnblen", Float, "sgrset", "sgrget", 0, 0)
+	@param.init("irmode", Fixnum, "sgiset", "sgiget", 0, 0)
+	
 #--------------------- common parameter -------------------------
-      @param.init("tonepat", Fixnum, "tonepat", "tonepatget", 3, 3)
-
-      @temp_param = @param.dup
-      @backup = @param.dup
+	@param.init("tonepat", Fixnum, "tonepat", "tonepatget", 3, 3)
+	
+	@temp_param = @param.dup
+	@backup = @param.dup
       
-    end
-    
-    private :param_init
+      end
+      
+      private :param_init
 
 #------------------- method for parameters----------------------
     
-    def set(key, val)
-      @param[key] = val
-    end
+      def set(key, val)
+	@param[key] = val
+      end
 
 # by kawanabe
 =begin
@@ -119,9 +120,9 @@ module AdvancedDCL
 
 =end
 
-    def get(key)
-      @param[key] = val
-    end
+      def get(key)
+	@param[key] = val
+      end
 
 # by kawanabe
 =begin
@@ -135,11 +136,11 @@ module AdvancedDCL
 
 =end
 
-    def gtla(max, min, dx)
-      @param.sync
-
-      DCL.uegtla(max, min, dx)
-    end
+      def gtla(max, min, dx)
+	@param.sync
+	
+	DCL.uegtla(max, min, dx)
+      end
 
 # by DCL manual
 =begin
@@ -156,11 +157,11 @@ module AdvancedDCL
 
 =end
 
-    def gtlb(z, dx)
-      @param.sync
-
-      DCL.uegtlb(z, z.shape[0], z.shape[0], z.shape[1], dx)
-    end
+      def gtlb(z, dx)
+	@param.sync
+	
+	DCL.uegtlb(z, z.shape[0], z.shape[0], z.shape[1], dx)
+      end
 
 # by DCL manual
 =begin
@@ -177,11 +178,11 @@ module AdvancedDCL
 
 =end
 
-    def stlv(tlev1, tlev2, ipat)
-      @param.sync
-
-      DCL.uestlv(tlev1, tlev2, ipat)
-    end
+      def stlv(tlev1, tlev2, ipat)
+	@param.sync
+	
+	DCL.uestlv(tlev1, tlev2, ipat)
+      end
 
 # by DCL manual
 =begin
@@ -205,14 +206,14 @@ module AdvancedDCL
     
 =end
 
-    def stln(tlevn, ipatn)
-      @param.sync
-
-      if(!(tlevn.length == ipatn.length + 1))
-	raise ArgumentError, "length mismatch between tone level & tone number"
+      def stln(tlevn, ipatn)
+	@param.sync
+	
+	if(!(tlevn.length == ipatn.length + 1))
+	  raise ArgumentError, "length mismatch between tone level & tone number"
+	end
+	DCL.uestln(tlevn, ipatn, ipatn.length)
       end
-      DCL.uestln(tlevn, ipatn, ipatn.length)
-    end
 
 # by DCL manual
 =begin
@@ -229,9 +230,9 @@ module AdvancedDCL
 
 =end
  
-    def itlv
-      DCL.ueitlv
-    end
+      def itlv
+	DCL.ueitlv
+      end
 
 # by DCL manual
 =begin
@@ -247,15 +248,15 @@ module AdvancedDCL
 
 =end
 
-    def levelget
-      nlev = DCL.ueqntl
-      levels = Array.new
-      for i in 1..nlev
-	status = DCL.ueqtlv(i)
-	levels.push(status)
+      def levelget
+	nlev = DCL.ueqntl
+	levels = Array.new
+	for i in 1..nlev
+	  status = DCL.ueqtlv(i)
+	  levels.push(status)
+	end
+	levels
       end
-      levels
-    end
 
 # by kawanabe
 =begin
@@ -273,43 +274,43 @@ module AdvancedDCL
 #----------------------------------------------------------
 #------------ draw method ----------------------
 
-    def draw(data, x=nil, y=nil, temp=nil)
-      if(!(y.is_a?(Hash)))
-	if(x.is_a?(Hash))
-	  temp = x.dup
-	  x = nil
-	elsif(Basics.typearray(x))
-	  if(!Basics.typearray(y))
-	    raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+      def draw(data, x=nil, y=nil, temp=nil)
+	if(!(y.is_a?(Hash)))
+	  if(x.is_a?(Hash))
+	    temp = x.dup
+	    x = nil
+	  elsif(Basics.typearray(x))
+	    if(!Basics.typearray(y))
+	      raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+	    end
 	  end
+	else
+	  raise ArgumentError, "both x & y must be Array or NArray(or nil)"
 	end
-      else
-	raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+	
+	nx = data.shape[0]
+	ny = data.shape[1]
+	
+	if(Basics.typearray(x) && Basics.typearray(y))
+	  DCL.uwsgxa(x, x.length)
+	  DCL.uwsgya(y, y.length)
+	  Basics.checkundef(x, y)
+	else
+	  Basics.checkundef(nx.to_f, ny.to_f)
+	end
+
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.uetone(data, nx, nx, ny)
+	
+	@backup.sync
+	@temp_param.clear
       end
 
-      nx = data.shape[0]
-      ny = data.shape[1]
-
-      if(Basics.typearray(x) && Basics.typearray(y))
-	DCL.uwsgxa(x, x.length)
-	DCL.uwsgya(y, y.length)
-	Basics.checkundef(x, y)
-      else
-	Basics.checkundef(nx.to_f, ny.to_f)
-      end
-
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-
-      Fig.settrf
-    
-      DCL.uetone(data, nx, nx, ny)
-
-      @backup.sync
-      @temp_param.clear
-    end
-
 # by DCL manual
 =begin
 ---Tone.draw(data, x=nil, y=nil, temp=nil)
@@ -334,42 +335,42 @@ module AdvancedDCL
 
 =end
  
-    def imdraw(data, x=nil, y=nil, temp=nil)
-      if(!(y.is_a?(Hash)))
-	if(x.is_a?(Hash))
-	  temp = x.dup
-	  x = nil
-	elsif(Basics.typearray(x))
-	  if(!Basics.typearray(y))
-	    raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+      def imdraw(data, x=nil, y=nil, temp=nil)
+	if(!(y.is_a?(Hash)))
+	  if(x.is_a?(Hash))
+	    temp = x.dup
+	    x = nil
+	  elsif(Basics.typearray(x))
+	    if(!Basics.typearray(y))
+	      raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+	    end
 	  end
+	else
+	  raise ArgumentError, "both x & y must be Array or NArray(or nil)"
 	end
-      else
-	raise ArgumentError, "both x & y must be Array or NArray(or nil)"
+	
+	nx = data.shape[0]
+	ny = data.shape[1]
+	
+	if(Basics.typearray(x) && Basics.typearray(y))
+	  DCL.uwsgxa(x, x.length)
+	  DCL.uwsgya(y, y.length)
+	  Basics.checkundef(x, y)
+	else
+	  Basics.checkundef(nx.to_f, ny.to_f)
+	end
+	
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.uetonf(data, nx, nx, ny)
+	@backup.sync
+	@temp_param.clear
       end
-
-      nx = data.shape[0]
-      ny = data.shape[1]
-
-      if(Basics.typearray(x) && Basics.typearray(y))
-	DCL.uwsgxa(x, x.length)
-	DCL.uwsgya(y, y.length)
-	Basics.checkundef(x, y)
-      else
-	Basics.checkundef(nx.to_f, ny.to_f)
-      end
-
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-
-      Fig.settrf
-    
-      DCL.uetonf(data, nx, nx, ny)
-      @backup.sync
-      @temp_param.clear
-    end
-
+      
 # by DCL manual
 =begin
 ---Tone.imdraw(data, x=nil, y=nil, temp=nil)
@@ -391,18 +392,18 @@ module AdvancedDCL
 
 =end
     
-    def fill(upx, upy, temp=nil)
-      Basics.checkundef(upx, upy)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-
-      Fig.settrf
-
-      DCL.sgtnu(upx.length, upx, upy)
-      @backup.sync
-      @temp_param.clear
-    end
+      def fill(upx, upy, temp=nil)
+	Basics.checkundef(upx, upy)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	
+	DCL.sgtnu(upx.length, upx, upy)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -420,17 +421,17 @@ module AdvancedDCL
 
 =end
 
-    def vfill(vpx, vpy, temp=nil)
-      Basics.checkundef(vpx, vpy)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-
-      DCL.sgtnv(vpx.length, vpx, vpy)
-      @backup.sync
-      @temp_param.clear
-    end
-
+      def vfill(vpx, vpy, temp=nil)
+	Basics.checkundef(vpx, vpy)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	DCL.sgtnv(vpx.length, vpx, vpy)
+	@backup.sync
+	@temp_param.clear
+      end
+      
 # by DCL manual
 =begin
 ---Tone.vfill(vpx, vpy, temp=nil)
@@ -447,17 +448,17 @@ module AdvancedDCL
 
 =end
 
-    def rfill(rpx, rpy, temp=nil)
-      Basics.checkundef(rpx, rpy)
-      @param.sync
-      @backup = @temp_param.set(temp, @param, @backup)
-      @temp_param.sync
-      
-      Fig.settrf
-      DCL.sgtnv(rpx.length, rpx, rpy)
-      @backup.sync
-      @temp_param.clear
-    end
+      def rfill(rpx, rpy, temp=nil)
+	Basics.checkundef(rpx, rpy)
+	@param.sync
+	@backup = @temp_param.set(temp, @param, @backup)
+	@temp_param.sync
+	
+	Fig.settrf
+	DCL.sgtnv(rpx.length, rpx, rpy)
+	@backup.sync
+	@temp_param.clear
+      end
 
 # by DCL manual
 =begin
@@ -474,52 +475,53 @@ module AdvancedDCL
     (3) ̈ʂԂg[p^[ԍ tonepat Őݒ肷. 
 
 =end
-    module_function :param_init
-    module_function :set
-    module_function :get
-    module_function :draw
-    module_function :imdraw
-    module_function :gtla
-    module_function :gtlb
-    module_function :stlv
-    module_function :stln
-    module_function :itlv
-    module_function :levelget
-    module_function :fill
-    module_function :vfill
-    module_function :rfill
-
-    param_init
-
+      module_function :param_init
+      module_function :set
+      module_function :get
+      module_function :draw
+      module_function :imdraw
+      module_function :gtla
+      module_function :gtlb
+      module_function :stlv
+      module_function :stln
+      module_function :itlv
+      module_function :levelget
+      module_function :fill
+      module_function :vfill
+      module_function :rfill
+      
+      param_init
+      
 #----------------------------------------------------------
     
-    def @param.tonepat(itpat)
-      DCL.ueiset("itpat", itpat)
-      DCL.sgstnp(itpat)
-    end
+      def @param.tonepat(itpat)
+	DCL.ueiset("itpat", itpat)
+	DCL.sgstnp(itpat)
+      end
+      
+      def @temp_param.tonepat(itpat)
+	DCL.ueiset("itpat", itpat)
+	DCL.sgstnp(itpat)
+      end
 
-    def @temp_param.tonepat(itpat)
-      DCL.ueiset("itpat", itpat)
-      DCL.sgstnp(itpat)
+      def @backup.tonepat(itpat)
+	DCL.ueiset("itpat", itpat)
+	DCL.sgstnp(itpat)
+      end
+      
+      def @param.tonepatget
+	DCL.ueiget("itpat")
+      end
+      
+      @param.keys.each{|i|
+	eval "def #{i}; @param['#{i}']; end"
+	eval "def #{i}=(val); set('#{i}', val); end"
+      }
+      
+      @param.keys.each{|i|
+	eval "module_function :#{i}"
+	eval "module_function :#{i}="
+      }
     end
-
-    def @backup.tonepat(itpat)
-      DCL.ueiset("itpat", itpat)
-      DCL.sgstnp(itpat)
-    end
-
-    def @param.tonepatget
-      DCL.ueiget("itpat")
-    end
-
-    @param.keys.each{|i|
-      eval "def #{i}; @param['#{i}']; end"
-      eval "def #{i}=(val); set('#{i}', val); end"
-    }
-  
-    @param.keys.each{|i|
-      eval "module_function :#{i}"
-      eval "module_function :#{i}="
-    }
   end
 end
